/*
 * Sun RPC is a product of Sun Microsystems, Inc. and is provided for
 * unrestricted use provided that this legend is included on all tape
 * media and as a part of the software program in whole or part.  Users
 * may copy or modify Sun RPC without charge, but are not authorized
 * to license or distribute it to anyone else except as part of a product or
 * program developed by the user.
 * 
 * SUN RPC IS PROVIDED AS IS WITH NO WARRANTIES OF ANY KIND INCLUDING THE
 * WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE OR TRADE PRACTICE.
 * 
 * Sun RPC is provided with no support and without any obligation on the
 * part of Sun Microsystems, Inc. to assist in its use, correction,
 * modification or enhancement.
 * 
 * SUN MICROSYSTEMS, INC. SHALL HAVE NO LIABILITY WITH RESPECT TO THE
 * INFRINGEMENT OF COPYRIGHTS, TRADE SECRETS OR ANY PATENTS BY SUN RPC
 * OR ANY PART THEREOF.
 * 
 * In no event will Sun Microsystems, Inc. be liable for any lost revenue
 * or profits or other special, indirect and consequential damages, even if
 * Sun has been advised of the possibility of such damages.
 * 
 * Sun Microsystems, Inc.
 * 2550 Garcia Avenue
 * Mountain View, California  94043
 */

#if !defined(lint) && defined(SCCSIDS)
static char sccsid[] = "@(#)util.c  1.3  89/12/27  Copyr 1988 Sun Micro";
#endif

/*
 * This file contains the utility routines for the performance suite.
 */


#include <stdio.h>
#ifdef MICROTIMER
#include <sys/types.h>
#include <sys/kstat.h>
#endif
#include <sys/time.h>

#define MILLION 1000000


#ifdef MICROTIMER

#ifdef JUPBETA
extern void gethrtime(hrtimer_t *);
#else
extern hrtime_t gethrtime(void);
#endif

getmicrotime(ltime, dummy)
long  *ltime;
long *dummy;
#else
int 
getmicrotime(tp, tzp)
struct timeval *tp;
struct timezone *tzp;
#endif
{

#ifdef MICROTIMER
#ifdef JUPBETA
	llsint_t cur_time;
	long secs;

	gethrtime((hrtimer_t *)&cur_time);
#else
	hrtime_t cur_time;
	long secs;

	cur_time = gethrtime();
	cur_time /= 1000;	/* convert nanosecs into microsecs */
#endif
	secs = (long) cur_time;
	*ltime = secs;
	return(1);

#else
		return(gettimeofday(tp,tzp));
#endif

}

char *
print_time(before, after)
#ifdef MICROTIMER
	long *before;
	long *after;
#else
	struct timeval *before;
	struct timeval *after;
#endif
{
	long secs;
	long usecs;
	static char buf[100];

#ifdef MICROTIMER

	usecs = *after - *before;
	if ( usecs > MILLION) {
		secs = usecs / MILLION;
		usecs = usecs - secs * MILLION;
	}
	else
		secs = 0;
	
#else
	secs = after->tv_sec - before->tv_sec;
	usecs = after->tv_usec - before->tv_usec;
	if (usecs < 0) {
		usecs += MILLION;
		secs -= 1;
	}
#endif
	sprintf(buf, "%9ld secs %9ld usecs ", secs, usecs);
	return(buf);
}


long
diff_time(before, after)
#ifdef MICROTIMER
	long *before;
	long *after;
#else
	struct timeval *before;
	struct timeval *after;
#endif
{
	long secs;
	long usecs;

#ifdef MICROTIMER
	usecs = *after - *before; 
#else
	secs = after->tv_sec - before->tv_sec;
	usecs = after->tv_usec - before->tv_usec;
	if (usecs < 0) {
		usecs += MILLION;
		secs -= 1;
	}
	usecs += (secs * MILLION);
#endif	
	return(usecs);
}

void
add_time(before, after, total)
#ifdef MICROTIMER
	long *before;
	long *after;
	long *total;
#else
	struct timeval *before, *after, *total;

#endif

{
	long secs;
	long usecs;

#ifdef MICROTIMER
	usecs = *after - *before; 
	*total += usecs;

#else

	secs = after->tv_sec - before->tv_sec;
	usecs = after->tv_usec - before->tv_usec;
	if (usecs < 0) {
		usecs += MILLION;
		secs -= 1;
	}
	total->tv_sec += secs;
	total->tv_usec += usecs;
	if (total->tv_usec > MILLION) {
		total->tv_sec += 1;
		total->tv_usec -= MILLION;
	}
#endif
}

void
fatal(s)
	char *s;
{
	fprintf(stderr, "%s\n", s);
	exit(1);
}

float
mspercall(usecs, calls)
	long usecs;
	int calls;
{
	if (calls)
		return (((float) usecs) / (1000.0 * calls));
	else
		return (0.0);
}

